@@ -15,6 +15,7 @@
 
 from __future__ import division, absolute_import
 
+import ctypes.util
 import functools
 import platform
 import six
@@ -26,11 +27,14 @@ try:
 except ImportError:
     from xcffib.ffi_build import ffi
 
-soname = "libxcb.so.1"
 if platform.system() == "Darwin":
     soname = "libxcb.dylib"
 elif platform.system() == "Windows":
     soname = "libxcb.dll"
+else:
+    soname = ctypes.util.find_library("xcb")
+    if soname is None:
+        soname = "libxcb.so"
 lib = ffi.dlopen(soname)
 
 __xcb_proto_version__ = "1.13"
@@ -411,7 +415,7 @@ class List(Protobj):
         old = unpacker.offset
 
         if isinstance(typ, str):
-            self.list = list(unpacker.unpack(typ * count))
+            self.list = list(unpacker.unpack("%d%s" % (count, typ)))
         elif count is not None:
             for _ in range(count):
                 item = typ(unpacker)
@@ -457,7 +461,7 @@ class List(Protobj):
 
     def to_atoms(self):
         """ A helper for converting a List of chars to an array of atoms """
-        return struct.unpack("<" + "I" * (len(self) // 4), b''.join(self))
+        return struct.unpack("<" + "%dI" % (len(self) // 4), b''.join(self))
 
     def buf(self):
         return self.raw
@@ -775,7 +779,7 @@ def pack_list(from_, pack_type):
             from_ = [six.int2byte(b) for i in from_ for b in to_bytes(i)]
 
     if isinstance(pack_type, six.string_types):
-        return struct.pack("=" + pack_type * len(from_), *from_)
+        return struct.pack("=%d%s" % (len(from_), pack_type), *from_)
     else:
         buf = six.BytesIO()
         for item in from_:
